This is a very simple app to retrieve data from google sheets using gsheets wrapper and plot it.
It takes in command line arguments as the two column names to plot with and returns an image with the plot
